@@ -25,11 +25,17 @@ def SaveAccounts(new_account, custom_TEMP_ACCOUNTS_PATH=None):
     c.execute(
         """CREATE TABLE IF NOT EXISTS account_list (address text, sequance_number integer, balance integer)"""
     )
-
-    c.execute(
-        "INSERT INTO account_list VALUES (?,?,?)",
-        (new_account.Address, new_account.sequance_number,
-         new_account.balance),
-    )
+    if type(new_account) == list:
+        for account in new_account:
+            c.execute(
+                """INSERT INTO account_list VALUES (?, ?, ?)""",
+                (account.Address, account.sequance_number, account.balance),
+            )
+    else:
+        c.execute(
+            """INSERT INTO account_list VALUES (?, ?, ?)""",
+            (new_account.Address, new_account.sequance_number,
+             new_account.balance),
+        )
     conn.commit()
     conn.close()
