@@ -35,11 +35,11 @@ def SaveBlock(
             custom_TEMP_ACCOUNTS_PATH=custom_TEMP_ACCOUNTS_PATH,
         )
         SaveBlockshash(
-            [block.previous_hash],
+            block.previous_hash,
             custom_TEMP_BLOCKSHASH_PATH=custom_TEMP_BLOCKSHASH_PATH,
         )
         SaveBlockshash_part(
-            [],
+            [block.previous_hash],
             custom_TEMP_BLOCKSHASH_PART_PATH=custom_TEMP_BLOCKSHASH_PART_PATH,
         )
         block.first_time = False
