@@ -4,11 +4,12 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
-
 from kivymd.uix.gridlayout import MDGridLayout
 from kivymd.uix.screen import MDScreen
 
-from decentra_network.lib.settings_system import the_settings, test_mode, debug_mode
+from decentra_network.lib.settings_system import d_mode_settings
+from decentra_network.lib.settings_system import t_mode_settings
+from decentra_network.lib.settings_system import the_settings
 
 
 class SettingsScreen(MDScreen):
@@ -21,7 +22,7 @@ class SettingsBox(MDGridLayout):
     t_first_status = the_settings()["test_mode"]
 
     def D_Status_Changing(self, instance, value):
-        debug_mode(value)
+        d_mode_settings(value)
 
     def T_Status_Changing(self, instance, value):
-        test_mode(value)
+        t_mode_settings(value)
