@@ -14,43 +14,51 @@ def Check_Type(transaction):
     Check if the transaction type is valid
     """
     if isinstance(transaction.sequance_number, int):
-        logger.info("sequance_number is int")
+        pass
     else:
+        logger.debug("sequance_number is not int")
         return False
 
     if isinstance(transaction.signature, str):
-        logger.info("signature is str")
+        pass
     else:
+        logger.debug("signature is not str")
         return False
 
     if isinstance(transaction.fromUser, str):
-        logger.info("fromUser is str")
+        pass
     else:
+        logger.debug("fromUser is not str")
         return False
 
     if isinstance(transaction.toUser, str):
-        logger.info("toUser is str")
+        pass
     else:
+        logger.debug("toUser is not str")
         return False
 
     if isinstance(transaction.data, str):
-        logger.info("data is str")
+        pass
     else:
+        logger.debug("data is not str")
         return False
 
     if isinstance(transaction.amount, (int, float)):
-        logger.info("amount is int&&float")
+        pass
     else:
+        logger.debug("amount is not int&&float")
         return False
 
     if isinstance(transaction.transaction_fee, (int, float)):
-        logger.info("transaction_fee is int&&float")
+        pass
     else:
+        logger.debug("transaction_fee is not int&&float")
         return False
 
     if isinstance(transaction.transaction_time, (int)):
-        logger.info("transaction_time is int")
+        pass
     else:
+        logger.debug("transaction_time is not int")
         return False
 
     return True
